FilePathRepositoryImpl class

파일 경로 리포지토리 구현체

Implemented types

Constructors

FilePathRepositoryImpl()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

calculateRelativeImportPath(String fromPath, String toPath) String
주어진 파일 경로에 대한 상대 경로를 계산합니다.
override
createFileInfos({required String modelName, required String projectRootPath, required String baseDir, required bool isFlat}) List<FileInfo>
주어진 모델명과 유형에 따른 파일 정보를 생성합니다.
override
generateImportsString(FileInfo fileInfo, Map<DaGenFileType, String> typeToPathMap) String
의존성 파일들에 대한 import 문자열을 생성합니다.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited