CommandRepository class abstract interface

명령어 처리를 담당하는 리포지토리 인터페이스

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isHelpRequested(ArgResults args) bool
도움말 요청인지 확인합니다.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseArguments(List<String> arguments) → ArgResults
명령어 인수를 파싱합니다.
printUsage() → void
사용법을 출력합니다.
toString() String
A string representation of this object.
inherited
validateModelName(List<String> rest) String
모델명이 유효한지 확인합니다.

Operators

operator ==(Object other) bool
The equality operator.
inherited